@@ -89,6 +89,11 @@ NS_DIM_PREFIX NodeIF, NS_DIM_PREFIX NodeAllIF;
 DDD_IF NS_DIM_PREFIX BorderVectorIF, NS_DIM_PREFIX BorderVectorSymmIF,
 NS_DIM_PREFIX OuterVectorIF, NS_DIM_PREFIX OuterVectorSymmIF,
 NS_DIM_PREFIX VectorVIF, NS_DIM_PREFIX VectorVAllIF, NS_DIM_PREFIX VectorIF;
+/* DDD interfaces for node communication */
+DDD_IF NS_DIM_PREFIX Node_InteriorBorder_All_IF;
+/* DDD interfaces for facet (side vector) communication */
+DDD_IF NS_DIM_PREFIX Facet_InteriorBorder_All_IF;
+
 /* DDD interfaces for edge communication */
 DDD_IF NS_DIM_PREFIX EdgeIF, NS_DIM_PREFIX BorderEdgeSymmIF, NS_DIM_PREFIX EdgeHIF, NS_DIM_PREFIX EdgeVHIF,
 NS_DIM_PREFIX EdgeSymmVHIF;
@@ -732,6 +737,11 @@ static void ddd_IfInit(DDD::DDDContext& context)
   dddctrl.NodeAllIF = DDD_IFDefine(context, 1,O,5,A,5,B);
   DDD_IFSetName(context, dddctrl.NodeAllIF, "NodeAllIF: All/All");
 
+  // The Dune InteriorBorder_All_Interface for nodes
+  A[0] = PrioMaster; A[1] = PrioBorder;
+  B[0] = PrioMaster; B[1] = PrioBorder; B[2] = PrioVGhost; B[3] = PrioHGhost; B[4] = PrioVHGhost;
+  dddctrl.Node_InteriorBorder_All_IF = DDD_IFDefine(context, 1,O,2,A,5,B);
+  DDD_IFSetName(context, dddctrl.Node_InteriorBorder_All_IF, "Node_InteriorBorder_All_IF: Master/Border->Master/Border/VGhost/HGhost/VHGhost");
 
   /* define vector interfaces */
   O[0] = dddctrl.TypeVector;
@@ -771,6 +781,13 @@ static void ddd_IfInit(DDD::DDDContext& context)
   dddctrl.VectorIF = DDD_IFDefine(context, 1,O,1,A,3,B);
   DDD_IFSetName(context, dddctrl.VectorIF, "VectorIF: Master->VGhost/VHGhost/HGhost");
 
+  // The Dune InteriorBorder_All_Interface for facets
+  A[0] = PrioMaster; A[1] = PrioBorder;
+  B[0] = PrioMaster; B[1] = PrioBorder; B[2] = PrioVGhost; B[3] = PrioHGhost; B[4] = PrioVHGhost;
+  dddctrl.Facet_InteriorBorder_All_IF = DDD_IFDefine(context, 1,O,2,A,5,B);
+  DDD_IFSetName(context, dddctrl.Facet_InteriorBorder_All_IF, "Facet_InteriorBorder_All_IF: Master/Border->Master/Border/VGhost/HGhost/VHGhost");
+
+
   /* define vertex interfaces */
   O[0] = dddctrl.TypeIVertex; O[1] = dddctrl.TypeBVertex;
 
