@@ -200,10 +200,11 @@ enum HandlerSets
 extern DDD_IF ElementIF, ElementSymmIF, ElementVIF, ElementSymmVIF,
               ElementVHIF, ElementSymmVHIF;
 extern DDD_IF BorderNodeIF, BorderNodeSymmIF, OuterNodeIF, NodeVIF,
-              NodeIF, NodeAllIF;
+              NodeIF, NodeAllIF, Node_InteriorBorder_All_IF;
 extern DDD_IF BorderVectorIF, BorderVectorSymmIF,
               OuterVectorIF, OuterVectorSymmIF,
               VectorVIF, VectorVAllIF, VectorIF;
+extern DDD_IF Facet_InteriorBorder_All_IF;
 extern DDD_IF EdgeIF, BorderEdgeSymmIF, EdgeHIF, EdgeVHIF,
               EdgeSymmVHIF;
 
@@ -253,10 +254,11 @@ struct DDD_CTRL
   DDD_IF ElementIF, ElementSymmIF, ElementVIF, ElementSymmVIF,
          ElementVHIF, ElementSymmVHIF;
   DDD_IF BorderNodeIF, BorderNodeSymmIF, OuterNodeIF, NodeVIF,
-         NodeIF, NodeAllIF;
+         NodeIF, NodeAllIF, Node_InteriorBorder_All_IF;
   DDD_IF BorderVectorIF, BorderVectorSymmIF,
          OuterVectorIF, OuterVectorSymmIF,
          VectorVIF, VectorVAllIF, VectorIF;
+  DDD_IF Facet_InteriorBorder_All_IF;
   DDD_IF VertexIF;
   DDD_IF EdgeIF, BorderEdgeSymmIF, EdgeHIF, EdgeVHIF,
          EdgeSymmVHIF;
